@@ -1,5 +1,5 @@
 package Language::LispPerl::BuiltIns;
-$Language::LispPerl::BuiltIns::VERSION = '0.002';
+$Language::LispPerl::BuiltIns::VERSION = '0.003';
 use Moo;
 
 use Carp;
@@ -27,6 +27,7 @@ has 'functions' => (
             # Completeness
             "eval"              => \&_impl_eval,
             "syntax"            => \&_impl_syntax,
+            "quote"             => \&_impl_quote,
 
             # Lisp file inclusion operation
             "require"           => \&_impl_require,
@@ -251,6 +252,12 @@ sub _impl_syntax{
     return $self->evaler()->bind( $ast->second() );
 }
 
+sub _impl_quote{
+    my ($self, $ast) = @_;
+    $ast->error("quote expects 1 argument") if $ast->size != 2;
+    return $ast->second();
+}
+
 # ( throw someexception "The message that goes with it")
 sub _impl_throw {
     my ( $self, $ast ) = @_;
