@@ -1,5 +1,5 @@
 package Language::LispPerl::Logger;
-$Language::LispPerl::Logger::VERSION = '0.002';
+$Language::LispPerl::Logger::VERSION = '0.003';
 use strict;
 use warnings;
 
@@ -10,7 +10,7 @@ use Log::Any qw/$log/;
 sub error {
     my $msg = shift;
     $log->error("$msg");
-    die $msg;
+    confess( $msg );
 }
 
 sub info {
