@@ -1,5 +1,5 @@
 package Language::LispPerl::Printer;
-$Language::LispPerl::Printer::VERSION = '0.002';
+$Language::LispPerl::Printer::VERSION = '0.003';
 use strict;
 use warnings;
 
@@ -82,6 +82,11 @@ sub to_string {
                 $s .= "]";
             }
         }
+        elsif( $type eq 'string' ){
+            $s = $obj->value();
+            $s =~ s/"/\\"/g;
+            $s = '"'.$s.'"';
+        }
         else {
             $s = $obj->value();
         }
